@@ -1,17 +1,25 @@
-package DB;
+package Devel::ebug::Backend;
+
 use strict;
 use warnings;
+
+our $VERSION = '0.61_01'; # TRIAL VERSION
+$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+
+package DB;
+
 use IO::Socket::INET;
 use String::Koremutake;
-# use YAML::Syck;
 use YAML;
 use Module::Pluggable
   search_path => 'Devel::ebug::Backend::Plugin',
   require     => 1;
 
-our $VERSION = "0.53_02";
 use vars qw(@dbline %dbline);
 
+our $VERSION = '0.61_01'; # TRIAL VERSION
+$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+
 # Let's catch INT signals and set a flag when they occur
 $SIG{INT} = sub {
   $DB::signal = 1;
@@ -26,6 +34,7 @@ my $context = {
   watch_points => [],
 };
 
+
 # Commands that the back end can respond to
 # Set record if the command changes start and should thus be recorded
 # in order for undo to work properly
@@ -51,7 +60,7 @@ sub DB {
     my %delete;
     foreach my $watch_point (@{ $context->{watch_points} }) {
       local $SIG{__WARN__} = sub { };
-      my $v = eval "package $package; $watch_point";
+      my $v = eval "package $package; $watch_point";  ## no critic (BuiltinFunctions::ProhibitStringyEval)
       if ($v) {
         $context->{watch_single} = 1;
         $delete{$watch_point} = 1;
@@ -70,9 +79,8 @@ sub DB {
     my $condition = break_point_condition($filename, $line);
     if ($condition) {
       local $SIG{__WARN__} = sub { };
-      my $v = eval "package $package; $condition";
+      my $v = eval "package $package; $condition";  ## no critic (BuiltinFunctions::ProhibitStringyEval)
       unless ($v) {
-
         # condition not true, go back to running
         $DB::single = 0;
         return;
@@ -132,13 +140,18 @@ sub initialise {
 sub put {
   my ($res) = @_;
   my $data = unpack("h*", Dump($res));
+  local $\; # if we run under perl -l the following line would get mangled
   $context->{socket}->print($data . "\n");
 }
 
 sub get {
   exit unless $context->{socket};
+  local $/= "\n";
   my $data = $context->{socket}->getline;
-  my $req = Load(pack("h*", $data));
+  my $req = do {
+    local $YAML::LoadBlessed = 1;
+    Load(pack("h*", $data));
+  };
   push @{ $context->{history} }, $req
     if exists $commands{ $req->{command} }->{record};
   return $req;
@@ -155,14 +168,14 @@ sub sub {
   $DB::single = 0 if defined $context->{mode} && $context->{mode} eq 'next';
 
   no strict 'refs';
-  if (wantarray) {
+  if (wantarray) { ## no critic (Freenode::Wantarray)
     my @ret   = &$sub;
     my $frame = pop @{ $context->{stack} };
     $DB::single = $frame->{single};
     $DB::single = 0 if defined $context->{mode} && $context->{mode} eq 'run' && !@{$context->{watch_points}};
 
-    if ($frame->{return}) {
-      return @{ $frame->{return} };
+    if ($frame->{'return'}) {
+      return @{ $frame->{'return'} };
     } else {
       return @ret;
     }
@@ -171,15 +184,34 @@ sub sub {
     my $frame = pop @{ $context->{stack} };
     $DB::single = $frame->{single};
     $DB::single = 0 if defined $context->{mode} && $context->{mode} eq 'run' && !@{$context->{watch_points}};
-    
-    if ($frame->{return}) {
-      return $frame->{return}->[0];
+
+    if ($frame->{'return'}) {
+      return $frame->{'return'}->[0];
     } else {
       return $ret;
     }
   }
 }
 
+sub DB::postponed {
+    # If this is a subroutine, let postponed_sub() deal with it.
+    goto &postponed_sub unless ref \$_[0] eq 'GLOB';
+
+    my ($filePath) = @_;
+    $filePath =~ s/^.*_<//;
+
+    my ($volume,$directories,$fileName) = File::Spec->splitpath( $filePath );
+
+    #test if the file name match with relative path/absolute path/single file name
+    if (exists $DB::break_on_load{$filePath}
+        || exists $DB::break_on_load{File::Spec->rel2abs( $filePath)}
+        || exists $DB::break_on_load{$fileName}){
+        $DB::single = 1;
+    }
+
+}
+
+
 sub fetch_codelines {
   my ($filename, @lines) = @_;
 
@@ -194,7 +226,7 @@ sub fetch_codelines {
   @codelines = map { defined($_) ? $_ : "" } @codelines;
 
   # remove newlines
-  @codelines = map { $_ =~ s/\s+$//; $_ } @codelines;
+  s/\s+$// for @codelines;
 
   # we run it with -d:ebug::Backend, so remove this extra line
   @codelines = grep { $_ ne 'use Devel::ebug::Backend;' } @codelines;
@@ -202,7 +234,7 @@ sub fetch_codelines {
   # for some reasons, the perl internals leave the opening POD line
   # around but strip the rest. so let's strip the opening POD line
   @codelines =
-    map { $_ =~ /^=(head|over|item|back|over|cut|pod|begin|end|for)/ ? "" : $_ }
+    map { /^=(head|over|item|back|over|cut|pod|begin|end|for)/ ? "" : $_ }
     @codelines;
 
   if (@lines) {
@@ -223,7 +255,8 @@ sub END {
   DB::fake::at_exit();
 }
 
-package DB::fake;
+package
+  DB::fake;
 
 sub at_exit {
   1;
@@ -233,3 +266,37 @@ package DB;    # Do not trace this 1; below!
 
 1;
 
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Devel::ebug::Backend
+
+=head1 VERSION
+
+version 0.61_01
+
+=head1 AUTHOR
+
+Original author: Leon Brocard E<lt>acme@astray.comE<gt>
+
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
+
+Contributors:
+
+Brock Wilcox E<lt>awwaiid@thelackthereof.orgE<gt>
+
+Taisuke Yamada
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2005-2020 by Leon Brocard.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
