@@ -1,4 +1,8 @@
 package Devel::ebug::Console;
+
+our $VERSION = '0.61_01'; # TRIAL VERSION
+$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+
 use strict;
 use warnings;
 use lib 'lib';
@@ -6,7 +10,6 @@ use Carp;
 use Class::Accessor::Chained::Fast;
 use Devel::ebug;
 use Term::ReadLine;
-use YAML::Syck;
 use base qw(Class::Accessor::Chained::Fast);
 
 sub run {
@@ -28,7 +31,7 @@ sub run {
   $ebug->backend($backend);
   $ebug->load;
 
-  my $codelines;
+  my $codelines = {};
 
   print "* Welcome to Devel::ebug $Devel::ebug::VERSION\n";
 
@@ -40,7 +43,7 @@ sub run {
     return unless $line =~ s/^x //;
     my @result = grep { /^\Q$line/ } keys %$pad;
     if ($line =~ /^[\$\@]/) {
-      @result = map { s/^[\$\@]//; $_ } @result;
+      s/^[\$\@]// for @result;
     }
     return @result;
   };
@@ -53,11 +56,11 @@ sub run {
       print "ebug: Program finished. Enter 'restart' or 'q'\n";
     } else {
       if ($list_always) {
-	show_codelines($codelines, $ebug, $list_lines_count) if($list_always);
+        show_codelines($codelines, $ebug, $list_lines_count) if($list_always);
       } else {
-	print $ebug->subroutine
-	  . "(" . $ebug->filename . "#" . $ebug->line . "):\n"
-	  . $ebug->codeline, "\n";
+        print $ebug->subroutine
+        . "(" . $ebug->filename . "#" . $ebug->line . "):\n"
+        . $ebug->codeline, "\n";
       }
     }
 
@@ -65,11 +68,12 @@ sub run {
     $command = "q" if not defined $command;
     $command = $last_command if ($command eq "");
 
-    if ($command =~ /[?h]/) {
+    if ($command =~ /^\s*[?h](elp)?\s*$/) {
       print 'Commands:
 
       b Set break point at a line number (eg: b 6, b code.pl 6, b code.pl 6 $x > 7,
       b Calc::fib)
+     bf break on file loading (eg: bf Calc.pm)
       d Delete a break point (d 6, d code.pl 6)
       e Eval Perl code and print the result (eg: e $x+$y)
       f Show all the filenames loaded
@@ -98,8 +102,8 @@ restart Restart the program
     } elsif ($command eq 'p') {
       my $pad = $ebug->pad_human;
       foreach my $k (sort keys %$pad) {
-	my $v = $pad->{$k};
-	print "  $k = $v;\n";
+        my $v = $pad->{$k};
+        print "  $k = $v;\n";
       }
     } elsif ($command eq 's') {
       $ebug->step;
@@ -110,7 +114,9 @@ restart Restart the program
       print "STDOUT:\n$stdout\n";
       print "STDERR:\n$stderr\n";
     } elsif ($command eq 'r') {
-      eval { $ebug->run };
+      $ebug->run;
+      # TODO: Consider using this instead:
+      # eval { $ebug->run };
     } elsif ($command eq 'restart') {
       $ebug->load;
     } elsif ($command =~ /^ret ?(.*)/) {
@@ -118,7 +124,7 @@ restart Restart the program
     } elsif ($command eq 'T') {
       my @trace = $ebug->stack_trace_human;
       foreach my $frame (@trace) {
-	print "$frame\n";
+        print "$frame\n";
       }
     } elsif ($command eq 'f') {
       print "$_\n" foreach $ebug->filenames;
@@ -129,6 +135,8 @@ restart Restart the program
       $ebug->break_point($1, $2, $3);
     } elsif ($command =~ /^b (.+)/) {
       $ebug->break_point_subroutine($1);
+    } elsif ($command =~ /^bf (.+)/) {
+      $ebug->break_on_load($1);
     } elsif ($command =~ /^d (.+?) (\d+)/) {
       $ebug->break_point_delete($1, $2);
     } elsif ($command =~ /^d (\d+)/) {
@@ -188,9 +196,17 @@ sub show_codelines {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Devel::ebug::Console - Console front end to Devel::ebug
+Devel::ebug::Console
+
+=head1 VERSION
+
+version 0.61_01
 
 =head1 SYNOPSIS
 
@@ -201,20 +217,34 @@ Devel::ebug::Console - Console front end to Devel::ebug
 
 =head1 DESCRIPTION
 
-L<Devel::ebug::Console> is an interactive commmand-line front end to L<Devel::ebug>. It
+L<Devel::ebug::Console> is an interactive command-line front end to L<Devel::ebug>. It
 is a simple Perl debugger, much like perl5db.pl.
 
+=head1 NAME
+
+Devel::ebug::Console - Console front end to Devel::ebug
+
 =head1 SEE ALSO
 
 L<Devel::ebug>, L<ebug>
 
 =head1 AUTHOR
 
-Leon Brocard, C<< <acme@astray.com> >>
+Original author: Leon Brocard E<lt>acme@astray.comE<gt>
 
-=head1 COPYRIGHT
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-Copyright (C) 2005, Leon Brocard
+Contributors:
 
-This program is free software; you can redistribute it or modify it
-under the same terms as Perl itself.
+Brock Wilcox E<lt>awwaiid@thelackthereof.orgE<gt>
+
+Taisuke Yamada
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2005-2020 by Leon Brocard.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
